/**
 * The default theme interface, augment this to avoid having to set the theme type everywhere.
 * Our [TypeScript guide on theme customization](https://mui.com/material-ui/customization/theming/#custom-variables) explains in detail how you would add custom properties.
 */
export interface DefaultTheme {}